@@ -18,7 +18,6 @@
 #include "databasetestdata.h"
 
 #include "file/localfilelisting.h"
-#include "musicaudiotrack.h"
 
 #include "config-upnp-qt.h"
 
@@ -29,12 +28,10 @@
 #include <QHash>
 #include <QVector>
 #include <QThread>
-#include <QMetaObject>
 #include <QStandardPaths>
 #include <QDir>
 #include <QFile>
 
-#include <QDebug>
 
 #include <QtTest>
 #include <QTest>
@@ -57,11 +54,9 @@ private Q_SLOTS:
     {
         qRegisterMetaType<QHash<qulonglong,int>>("QHash<qulonglong,int>");
         qRegisterMetaType<QHash<QString,QUrl>>("QHash<QString,QUrl>");
-        qRegisterMetaType<QList<MusicAudioTrack>>("QList<MusicAudioTrack>");
         qRegisterMetaType<QVector<qlonglong>>("QVector<qlonglong>");
         qRegisterMetaType<QHash<qlonglong,int>>("QHash<qlonglong,int>");
         qRegisterMetaType<QList<QUrl>>("QList<QUrl>");
-        qRegisterMetaType<NotificationItem>("NotificationItem");
     }
 
     void initialTestWithNoTrack()
@@ -122,13 +117,13 @@ private Q_SLOTS:
         QCOMPARE(removedTracksListSpy.count(), 0);
 
         const auto &firstNewTracksSignal = tracksListSpy.at(0);
-        auto firstNewTracks = firstNewTracksSignal.at(0).value<QList<MusicAudioTrack>>();
+        auto firstNewTracks = firstNewTracksSignal.at(0).value<DataTypes::ListTrackDataType>();
         const auto &secondNewTracksSignal = tracksListSpy.at(1);
-        auto secondNewTracks = secondNewTracksSignal.at(0).value<QList<MusicAudioTrack>>();
+        auto secondNewTracks = secondNewTracksSignal.at(0).value<DataTypes::ListTrackDataType>();
         auto newCovers = secondNewTracksSignal.at(1).value<QHash<QString, QUrl>>();
 
-        QCOMPARE(firstNewTracks.count() + secondNewTracks.count(), 3);
-        QCOMPARE(newCovers.count(), 3);
+        QCOMPARE(firstNewTracks.count() + secondNewTracks.count(), 5);
+        QCOMPARE(newCovers.count(), 5);
     }
 
     void addAndRemoveTracks()
@@ -181,7 +176,7 @@ private Q_SLOTS:
         QCOMPARE(removedTracksListSpy.count(), 0);
 
         auto newTracksSignal = tracksListSpy.at(0);
-        auto newTracks = newTracksSignal.at(0).value<QList<MusicAudioTrack>>();
+        auto newTracks = newTracksSignal.at(0).value<DataTypes::ListTrackDataType>();
         auto newCovers = newTracksSignal.at(1).value<QHash<QString, QUrl>>();
 
         QCOMPARE(newTracks.count(), 1);
@@ -216,7 +211,7 @@ private Q_SLOTS:
         QCOMPARE(removedTracksListSpy.count(), 1);
 
         auto newTracksSignalLast = tracksListSpy.at(1);
-        auto newTracksLast = newTracksSignalLast.at(0).value<QList<MusicAudioTrack>>();
+        auto newTracksLast = newTracksSignalLast.at(0).value<DataTypes::ListTrackDataType>();
         auto newCoversLast = newTracksSignalLast.at(1).value<QHash<QString, QUrl>>();
 
         QCOMPARE(newTracksLast.count(), 1);
@@ -275,7 +270,7 @@ private Q_SLOTS:
         QCOMPARE(removedTracksListSpy.count(), 0);
 
         auto newTracksSignal = tracksListSpy.at(0);
-        auto newTracks = newTracksSignal.at(0).value<QList<MusicAudioTrack>>();
+        auto newTracks = newTracksSignal.at(0).value<DataTypes::ListTrackDataType>();
         auto newCovers = newTracksSignal.at(1).value<QHash<QString, QUrl>>();
 
         QCOMPARE(newTracks.count(), 1);
@@ -310,7 +305,7 @@ private Q_SLOTS:
         QCOMPARE(removedTracksListSpy.count(), 1);
 
         auto newTracksSignalLast = tracksListSpy.at(1);
-        auto newTracksLast = newTracksSignalLast.at(0).value<QList<MusicAudioTrack>>();
+        auto newTracksLast = newTracksSignalLast.at(0).value<DataTypes::ListTrackDataType>();
         auto newCoversLast = newTracksSignalLast.at(1).value<QHash<QString, QUrl>>();
 
         QCOMPARE(newTracksLast.count(), 1);
@@ -379,7 +374,7 @@ private Q_SLOTS:
         QCOMPARE(modifiedTracksListSpy.count(), 0);
 
         auto newTracksSignal = tracksListSpy.at(0);
-        auto newTracks = newTracksSignal.at(0).value<QList<MusicAudioTrack>>();
+        auto newTracks = newTracksSignal.at(0).value<DataTypes::ListTrackDataType>();
         auto newCovers = newTracksSignal.at(1).value<QHash<QString, QUrl>>();
 
         QCOMPARE(newTracks.count(), 1);
@@ -416,7 +411,7 @@ private Q_SLOTS:
         QCOMPARE(modifiedTracksListSpy.count(), 0);
 
         auto newTracksSignalLast = tracksListSpy.at(1);
-        auto newTracksLast = newTracksSignalLast.at(0).value<QList<MusicAudioTrack>>();
+        auto newTracksLast = newTracksSignalLast.at(0).value<DataTypes::ListTrackDataType>();
         auto newCoversLast = newTracksSignalLast.at(1).value<QHash<QString, QUrl>>();
 
         QCOMPARE(newTracksLast.count(), 1);
@@ -432,8 +427,6 @@ private Q_SLOTS:
         QSignalSpy modifiedTracksListSpy(&myListing, &LocalFileListing::modifyTracksList);
         QSignalSpy indexingStartedSpy(&myListing, &LocalFileListing::indexingStarted);
         QSignalSpy indexingFinishedSpy(&myListing, &LocalFileListing::indexingFinished);
-        QSignalSpy newNotificationSpy(&myListing, &LocalFileListing::newNotification);
-        QSignalSpy closeNotificationSpy(&myListing, &LocalFileListing::closeNotification);
         QSignalSpy askRestoredTracksSpy(&myListing, &LocalFileListing::askRestoredTracks);
 
         QCOMPARE(tracksListSpy.count(), 0);
@@ -441,8 +434,6 @@ private Q_SLOTS:
         QCOMPARE(modifiedTracksListSpy.count(), 0);
         QCOMPARE(indexingStartedSpy.count(), 0);
         QCOMPARE(indexingFinishedSpy.count(), 0);
-        QCOMPARE(newNotificationSpy.count(), 0);
-        QCOMPARE(closeNotificationSpy.count(), 0);
         QCOMPARE(askRestoredTracksSpy.count(), 0);
 
         myListing.setAllRootPaths({QStringLiteral("/does/not/exists")});
@@ -452,8 +443,6 @@ private Q_SLOTS:
         QCOMPARE(modifiedTracksListSpy.count(), 0);
         QCOMPARE(indexingStartedSpy.count(), 0);
         QCOMPARE(indexingFinishedSpy.count(), 0);
-        QCOMPARE(newNotificationSpy.count(), 0);
-        QCOMPARE(closeNotificationSpy.count(), 0);
         QCOMPARE(askRestoredTracksSpy.count(), 0);
 
         myListing.init();
@@ -463,8 +452,6 @@ private Q_SLOTS:
         QCOMPARE(modifiedTracksListSpy.count(), 0);
         QCOMPARE(indexingStartedSpy.count(), 0);
         QCOMPARE(indexingFinishedSpy.count(), 0);
-        QCOMPARE(newNotificationSpy.count(), 0);
-        QCOMPARE(closeNotificationSpy.count(), 0);
         QCOMPARE(askRestoredTracksSpy.count(), 1);
 
         myListing.restoredTracks({{QUrl::fromLocalFile(QStringLiteral("/removed/files1")), QDateTime::fromMSecsSinceEpoch(1)},
@@ -475,8 +462,6 @@ private Q_SLOTS:
         QCOMPARE(modifiedTracksListSpy.count(), 0);
         QCOMPARE(indexingStartedSpy.count(), 1);
         QCOMPARE(indexingFinishedSpy.count(), 0);
-        QCOMPARE(newNotificationSpy.count(), 0);
-        QCOMPARE(closeNotificationSpy.count(), 0);
         QCOMPARE(askRestoredTracksSpy.count(), 1);
 
         auto removedTracksSignal = removedTracksListSpy.at(0);
