@@ -22,7 +22,6 @@
 #include "vlcLogging.h"
 #include "powermanagementinterface.h"
 
-#include <QTimer>
 #include <QAudio>
 #include <QDir>
 
@@ -161,8 +160,11 @@ QUrl AudioWrapper::source() const
     if (!d->mPlayer) {
         return {};
     }
-
-    return {}/*d->mPlayer.media().canonicalUrl()*/;
+    if (d->mMedia) {
+        auto filePath = QString::fromUtf8(libvlc_media_get_mrl(d->mMedia));
+        return QUrl::fromUserInput(filePath);
+    }
+    return {};
 }
 
 QMediaPlayer::Error AudioWrapper::error() const
@@ -193,15 +195,6 @@ bool AudioWrapper::seekable() const
     return d->mIsSeekable;
 }
 
-QAudio::Role AudioWrapper::audioRole() const
-{
-    if (!d->mPlayer) {
-        return {};
-    }
-
-    return {}/*d->mPlayer.audioRole()*/;
-}
-
 QMediaPlayer::State AudioWrapper::playbackState() const
 {
     return d->mPreviousPlayerState;
@@ -233,7 +226,14 @@ void AudioWrapper::setVolume(qreal volume)
 
 void AudioWrapper::setSource(const QUrl &source)
 {
-    d->mMedia = libvlc_media_new_path(d->mInstance, QDir::toNativeSeparators(source.toLocalFile()).toUtf8().constData());
+    if (source.isLocalFile()) {
+        qCDebug(orgKdeElisaPlayerVlc) << "AudioWrapper::setSource reading local resource";
+        d->mMedia = libvlc_media_new_path(d->mInstance, QDir::toNativeSeparators(source.toLocalFile()).toUtf8().constData());
+    } else {
+        qCDebug(orgKdeElisaPlayerVlc) << "AudioWrapper::setSource reading remote resource";
+        d->mMedia = libvlc_media_new_location(d->mInstance, source.url().toUtf8().constData());
+    }
+
     if (!d->mMedia) {
         qCDebug(orgKdeElisaPlayerVlc) << "AudioWrapper::setSource"
                  << "failed creating media"
@@ -327,11 +327,6 @@ void AudioWrapper::seek(qint64 position)
     setPosition(position);
 }
 
-void AudioWrapper::setAudioRole(QAudio::Role audioRole)
-{
-    //    d->mPlayer.setAudioRole(audioRole);
-}
-
 void AudioWrapper::mediaStatusChanged()
 {
 }
@@ -557,6 +552,13 @@ void AudioWrapperPrivate::signalPositionChange(float newPosition)
 
         mParent->playerPositionSignalChanges(mPreviousPosition);
     }
+
+    if (this->mMedia) {
+        QString title = QLatin1String(libvlc_media_get_meta(this->mMedia, libvlc_meta_Title));
+        QString nowPlaying = QLatin1String(libvlc_media_get_meta(this->mMedia, libvlc_meta_NowPlaying));
+
+        Q_EMIT mParent->currentPlayingForRadiosChanged(title, nowPlaying);
+    }
 }
 
 void AudioWrapperPrivate::signalSeekableChange(bool isSeekable)
