@@ -22,6 +22,8 @@
 
 class AsyncImageResponse : public QQuickImageResponse, public QRunnable
 {
+    Q_OBJECT
+
 public:
     AsyncImageResponse(QString id, QSize requestedSize)
         : QQuickImageResponse(), mId(std::move(id)), mRequestedSize(requestedSize)
@@ -63,3 +65,5 @@ QQuickImageResponse *EmbeddedCoverageImageProvider::requestImageResponse(const Q
     pool.start(response.get());
     return response.release();
 }
+
+#include "embeddedcoverageimageprovider.moc"
