@@ -20,20 +20,12 @@
 
 #include "elisaLib_export.h"
 
-#include "musicaudiotrack.h"
-
-#include <QUrl>
-#include <QMimeDatabase>
-#include <QObject>
+#include "datatypes.h"
 
 #include <memory>
 
-namespace Baloo {
-
-class File;
-
-}
-
+class QFileInfo;
+class QUrl;
 class FileScannerPrivate;
 
 class ELISALIB_EXPORT FileScanner
@@ -42,16 +34,24 @@ public:
 
     FileScanner();
 
-    virtual ~FileScanner();
+    ~FileScanner();
 
-    MusicAudioTrack scanOneFile(const QUrl &scanFile, const QMimeDatabase &mimeDatabase);
+    bool shouldScanFile(const QString &scanFile);
 
-    void scanProperties(const Baloo::File &match, MusicAudioTrack &trackData);
+    DataTypes::TrackDataType scanOneFile(const QUrl &scanFile);
 
-    void scanProperties(const QString &localFileName, MusicAudioTrack &trackData);
+    DataTypes::TrackDataType scanOneFile(const QUrl &scanFile, const QFileInfo &scanFileInfo);
+
+    DataTypes::TrackDataType scanOneBalooFile(const QUrl &scanFile, const QFileInfo &scanFileInfo);
+
+    QUrl searchForCoverFile(const QString &localFileName);
 
 private:
 
+    void scanProperties(const QString &localFileName, DataTypes::TrackDataType &trackData);
+
+    bool checkEmbeddedCoverImage(const QString &localFileName);
+
     std::unique_ptr<FileScannerPrivate> d;
 
 };
