@@ -18,7 +18,6 @@
 #include "manageheaderbar.h"
 
 #include <QTime>
-#include <QTimer>
 
 ManageHeaderBar::ManageHeaderBar(QObject *parent)
     : QObject(parent)
@@ -170,7 +169,13 @@ QVariant ManageHeaderBar::artist() const
         return QString();
     }
 
-    return mCurrentTrack.data(mArtistRole);
+    auto artistValue = mCurrentTrack.data(mArtistRole);
+
+    if (!artistValue.isValid()) {
+        return mCurrentTrack.data(mAlbumArtistRole);
+    }
+
+    return artistValue;
 }
 
 QUrl ManageHeaderBar::image() const
@@ -348,7 +353,11 @@ void ManageHeaderBar::setCurrentTrack(const QPersistentModelIndex &currentTrack)
 {
     mCurrentTrack = currentTrack;
     Q_EMIT currentTrackChanged();
+    updateCurrentTrackData();
+}
 
+void ManageHeaderBar::updateCurrentTrackData()
+{
     notifyArtistProperty();
     notifyTitleProperty();
     notifyAlbumProperty();
