@@ -23,10 +23,7 @@
 #include "elisautils.h"
 
 #include <QObject>
-#include <QList>
 #include <QPersistentModelIndex>
-#include <QAbstractItemModel>
-#include <QModelIndex>
 #include <QUrl>
 
 class ELISALIB_EXPORT ManageHeaderBar : public QObject
@@ -222,6 +219,8 @@ public Q_SLOTS:
 
     void setCurrentTrack(const QPersistentModelIndex &currentTrack);
 
+    void updateCurrentTrackData();
+
     void setArtistRole(int value);
 
     void setTitleRole(int value);
