@@ -22,20 +22,21 @@
 #ifndef MEDIACENTER_MPRIS2_H
 #define MEDIACENTER_MPRIS2_H
 
+#include "elisaLib_export.h"
+
 #include <QObject>
 #include <QSharedPointer>
-#include <QVariantMap>
+#include <memory>
 
 class MediaPlayer2Player;
 class MediaPlayer2;
-class QAbstractItemModel;
-class MediaPlayList;
+class MediaPlayListProxyModel;
 class ManageAudioPlayer;
 class ManageMediaPlayerControl;
 class ManageHeaderBar;
 class AudioWrapper;
 
-class Mpris2 : public QObject
+class ELISALIB_EXPORT Mpris2 : public QObject
 {
     Q_OBJECT
 
@@ -44,16 +45,11 @@ class Mpris2 : public QObject
                WRITE setPlayerName
                NOTIFY playerNameChanged)
 
-    Q_PROPERTY(QAbstractItemModel* playListModel
+    Q_PROPERTY(MediaPlayListProxyModel* playListModel
                READ playListModel
                WRITE setPlayListModel
                NOTIFY playListModelChanged)
 
-    Q_PROPERTY(MediaPlayList* playListControler
-               READ playListControler
-               WRITE setPlayListControler
-               NOTIFY playListControlerChanged)
-
     Q_PROPERTY(ManageAudioPlayer* audioPlayerManager
                READ audioPlayerManager
                WRITE setAudioPlayerManager
@@ -74,15 +70,18 @@ class Mpris2 : public QObject
                WRITE setAudioPlayer
                NOTIFY audioPlayerChanged)
 
+    Q_PROPERTY(bool showProgressOnTaskBar
+               READ showProgressOnTaskBar
+               WRITE setShowProgressOnTaskBar
+               NOTIFY showProgressOnTaskBarChanged)
+
 public:
     explicit Mpris2(QObject* parent = nullptr);
     ~Mpris2() override;
 
     QString playerName() const;
 
-    QAbstractItemModel* playListModel() const;
-
-    MediaPlayList* playListControler() const;
+    MediaPlayListProxyModel* playListModel() const;
 
     ManageAudioPlayer* audioPlayerManager() const;
 
@@ -92,13 +91,13 @@ public:
 
     AudioWrapper* audioPlayer() const;
 
+    bool showProgressOnTaskBar() const;
+
 public Q_SLOTS:
 
     void setPlayerName(const QString &playerName);
 
-    void setPlayListModel(QAbstractItemModel* playListModel);
-
-    void setPlayListControler(MediaPlayList* playListControler);
+    void setPlayListModel(MediaPlayListProxyModel* playListModel);
 
     void setAudioPlayerManager(ManageAudioPlayer* audioPlayerManager);
 
@@ -108,6 +107,8 @@ public Q_SLOTS:
 
     void setAudioPlayer(AudioWrapper* audioPlayer);
 
+    void setShowProgressOnTaskBar(bool value);
+
 Q_SIGNALS:
     void raisePlayer();
 
@@ -115,8 +116,6 @@ Q_SIGNALS:
 
     void playListModelChanged();
 
-    void playListControlerChanged();
-
     void audioPlayerManagerChanged();
 
     void manageMediaPlayerControlChanged();
@@ -125,19 +124,21 @@ Q_SIGNALS:
 
     void audioPlayerChanged();
 
+    void showProgressOnTaskBarChanged();
+
 private:
 
     void initDBusService();
 
-    MediaPlayer2 *m_mp2 = nullptr;
-    MediaPlayer2Player *m_mp2p = nullptr;
+    std::unique_ptr<MediaPlayer2> m_mp2;
+    std::unique_ptr<MediaPlayer2Player> m_mp2p;
     QString m_playerName;
-    QAbstractItemModel* m_playListModel = nullptr;
-    MediaPlayList* m_playListControler = nullptr;
+    MediaPlayListProxyModel* m_playListModel = nullptr;
     ManageAudioPlayer* m_manageAudioPlayer = nullptr;
     ManageMediaPlayerControl* m_manageMediaPlayerControl = nullptr;
     ManageHeaderBar* m_manageHeaderBar = nullptr;
     AudioWrapper* m_audioPlayer = nullptr;
+    bool mShowProgressOnTaskBar = true;
 };
 
 #endif //MEDIACENTER_MPRIS2_H
